# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_time.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import delivery_category_pb2 as v1_dot_rules_dot_delivery__category__pb2
from omni.pro.protos.v1.rules import delivery_locality_pb2 as v1_dot_rules_dot_delivery__locality__pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cv1/rules/delivery_time.proto\x12\'pro.omni.oms.api.v1.rules.delivery_time\x1a\x11\x63ommon/base.proto\x1a\x1ev1/rules/delivery_method.proto\x1a v1/rules/delivery_locality.proto\x1a\x18v1/rules/warehouse.proto\x1a v1/rules/delivery_category.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc9\x06\n\x0c\x44\x65liveryTime\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12S\n\x10\x64\x65livery_methods\x18\x04 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x45\n\rwarehouses_to\x18\x05 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12G\n\x0fwarehouses_from\x18\x06 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12Y\n\x12locality_available\x18\x07 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12\x11\n\ttime_type\x18\x08 \x01(\t\x12.\n\tvalue_min\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12.\n\tvalue_max\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\tinversely\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x17\n\x0fvariable_factor\x18\x0c \x01(\t\x12\x17\n\x0foperator_factor\x18\r \x01(\t\x12\x15\n\ramount_factor\x18\x0e \x01(\x02\x12\x64\n\x1d\x63\x61tegory_template_not_allowed\x18\x0f \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategory\x12*\n\x06\x61\x63tive\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x11 \x01(\t\x12?\n\x0cobject_audit\x18\x12 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xd1\x03\n\x19\x44\x65liveryTimeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x1d\n\x15locality_available_id\x18\x03 \x01(\t\x12\x11\n\ttime_type\x18\x04 \x01(\t\x12\x11\n\tvalue_min\x18\x05 \x01(\x05\x12\x11\n\tvalue_max\x18\x06 \x01(\x05\x12\x18\n\x10warehouse_to_ids\x18\x07 \x03(\x05\x12\x1a\n\x12warehouse_from_ids\x18\x08 \x03(\x05\x12\x1b\n\x13\x64\x65livery_method_ids\x18\t \x03(\t\x12-\n\tinversely\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12\x17\n\x0fvariable_factor\x18\x0c \x01(\t\x12\x17\n\x0foperator_factor\x18\r \x01(\t\x12\x15\n\ramount_factor\x18\x0e \x01(\x02\x12(\n category_template_not_allowed_id\x18\x0f \x01(\t\x12\x36\n\x07\x63ontext\x18\x10 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1a\x44\x65liveryTimeCreateResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf5\x02\n\x17\x44\x65liveryTimeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xef\x01\n\x18\x44\x65liveryTimeReadResponse\x12M\n\x0e\x64\x65livery_times\x18\x01 \x03(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa1\x01\n\x19\x44\x65liveryTimeUpdateRequest\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1a\x44\x65liveryTimeUpdateResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"_\n\x19\x44\x65liveryTimeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1a\x44\x65liveryTimeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x84\x01\n\x16\x41\x64\x64WarehousesToRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x18\n\x10warehouse_to_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb2\x01\n\x17\x41\x64\x64WarehousesToResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x87\x01\n\x19RemoveWarehousesToRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x18\n\x10warehouse_to_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aRemoveWarehousesToResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x88\x01\n\x18\x41\x64\x64WarehousesFromRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x1a\n\x12warehouse_from_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb4\x01\n\x19\x41\x64\x64WarehousesFromResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x01\n\x1bRemoveWarehousesFromRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x1a\n\x12warehouse_from_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x01\n\x1cRemoveWarehousesFromResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x89\x01\n\x18\x41\x64\x64\x44\x65liveryMethodRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x1b\n\x13\x64\x65livery_method_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb4\x01\n\x19\x41\x64\x64\x44\x65liveryMethodResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8c\x01\n\x1bRemoveDeliveryMethodRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x1b\n\x13\x64\x65livery_method_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x01\n\x1cRemoveDeliveryMethodResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe0\x0c\n\x13\x44\x65liveryTimeService\x12\x9f\x01\n\x12\x44\x65liveryTimeCreate\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeCreateRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeCreateResponse"\x00\x12\x99\x01\n\x10\x44\x65liveryTimeRead\x12@.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeReadRequest\x1a\x41.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeReadResponse"\x00\x12\x9f\x01\n\x12\x44\x65liveryTimeUpdate\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeUpdateRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeUpdateResponse"\x00\x12\x9f\x01\n\x12\x44\x65liveryTimeDelete\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeDeleteRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeDeleteResponse"\x00\x12\x96\x01\n\x0f\x41\x64\x64WarehousesTo\x12?.pro.omni.oms.api.v1.rules.delivery_time.AddWarehousesToRequest\x1a@.pro.omni.oms.api.v1.rules.delivery_time.AddWarehousesToResponse"\x00\x12\x9f\x01\n\x12RemoveWarehousesTo\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.RemoveWarehousesToRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.RemoveWarehousesToResponse"\x00\x12\x9c\x01\n\x11\x41\x64\x64WarehousesFrom\x12\x41.pro.omni.oms.api.v1.rules.delivery_time.AddWarehousesFromRequest\x1a\x42.pro.omni.oms.api.v1.rules.delivery_time.AddWarehousesFromResponse"\x00\x12\xa5\x01\n\x14RemoveWarehousesFrom\x12\x44.pro.omni.oms.api.v1.rules.delivery_time.RemoveWarehousesFromRequest\x1a\x45.pro.omni.oms.api.v1.rules.delivery_time.RemoveWarehousesFromResponse"\x00\x12\x9c\x01\n\x11\x41\x64\x64\x44\x65liveryMethod\x12\x41.pro.omni.oms.api.v1.rules.delivery_time.AddDeliveryMethodRequest\x1a\x42.pro.omni.oms.api.v1.rules.delivery_time.AddDeliveryMethodResponse"\x00\x12\xa5\x01\n\x14RemoveDeliveryMethod\x12\x44.pro.omni.oms.api.v1.rules.delivery_time.RemoveDeliveryMethodRequest\x1a\x45.pro.omni.oms.api.v1.rules.delivery_time.RemoveDeliveryMethodResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_time_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYTIME"]._serialized_start = 251
    _globals["_DELIVERYTIME"]._serialized_end = 1092
    _globals["_DELIVERYTIMECREATEREQUEST"]._serialized_start = 1095
    _globals["_DELIVERYTIMECREATEREQUEST"]._serialized_end = 1560
    _globals["_DELIVERYTIMECREATERESPONSE"]._serialized_start = 1563
    _globals["_DELIVERYTIMECREATERESPONSE"]._serialized_end = 1744
    _globals["_DELIVERYTIMEREADREQUEST"]._serialized_start = 1747
    _globals["_DELIVERYTIMEREADREQUEST"]._serialized_end = 2120
    _globals["_DELIVERYTIMEREADRESPONSE"]._serialized_start = 2123
    _globals["_DELIVERYTIMEREADRESPONSE"]._serialized_end = 2362
    _globals["_DELIVERYTIMEUPDATEREQUEST"]._serialized_start = 2365
    _globals["_DELIVERYTIMEUPDATEREQUEST"]._serialized_end = 2526
    _globals["_DELIVERYTIMEUPDATERESPONSE"]._serialized_start = 2529
    _globals["_DELIVERYTIMEUPDATERESPONSE"]._serialized_end = 2710
    _globals["_DELIVERYTIMEDELETEREQUEST"]._serialized_start = 2712
    _globals["_DELIVERYTIMEDELETEREQUEST"]._serialized_end = 2807
    _globals["_DELIVERYTIMEDELETERESPONSE"]._serialized_start = 2809
    _globals["_DELIVERYTIMEDELETERESPONSE"]._serialized_end = 2912
    _globals["_ADDWAREHOUSESTOREQUEST"]._serialized_start = 2915
    _globals["_ADDWAREHOUSESTOREQUEST"]._serialized_end = 3047
    _globals["_ADDWAREHOUSESTORESPONSE"]._serialized_start = 3050
    _globals["_ADDWAREHOUSESTORESPONSE"]._serialized_end = 3228
    _globals["_REMOVEWAREHOUSESTOREQUEST"]._serialized_start = 3231
    _globals["_REMOVEWAREHOUSESTOREQUEST"]._serialized_end = 3366
    _globals["_REMOVEWAREHOUSESTORESPONSE"]._serialized_start = 3369
    _globals["_REMOVEWAREHOUSESTORESPONSE"]._serialized_end = 3550
    _globals["_ADDWAREHOUSESFROMREQUEST"]._serialized_start = 3553
    _globals["_ADDWAREHOUSESFROMREQUEST"]._serialized_end = 3689
    _globals["_ADDWAREHOUSESFROMRESPONSE"]._serialized_start = 3692
    _globals["_ADDWAREHOUSESFROMRESPONSE"]._serialized_end = 3872
    _globals["_REMOVEWAREHOUSESFROMREQUEST"]._serialized_start = 3875
    _globals["_REMOVEWAREHOUSESFROMREQUEST"]._serialized_end = 4014
    _globals["_REMOVEWAREHOUSESFROMRESPONSE"]._serialized_start = 4017
    _globals["_REMOVEWAREHOUSESFROMRESPONSE"]._serialized_end = 4200
    _globals["_ADDDELIVERYMETHODREQUEST"]._serialized_start = 4203
    _globals["_ADDDELIVERYMETHODREQUEST"]._serialized_end = 4340
    _globals["_ADDDELIVERYMETHODRESPONSE"]._serialized_start = 4343
    _globals["_ADDDELIVERYMETHODRESPONSE"]._serialized_end = 4523
    _globals["_REMOVEDELIVERYMETHODREQUEST"]._serialized_start = 4526
    _globals["_REMOVEDELIVERYMETHODREQUEST"]._serialized_end = 4666
    _globals["_REMOVEDELIVERYMETHODRESPONSE"]._serialized_start = 4669
    _globals["_REMOVEDELIVERYMETHODRESPONSE"]._serialized_end = 4852
    _globals["_DELIVERYTIMESERVICE"]._serialized_start = 4855
    _globals["_DELIVERYTIMESERVICE"]._serialized_end = 6487
# @@protoc_insertion_point(module_scope)
