# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import holidays_pb2 as v1_dot_rules_dot_holidays__pb2


class HolidaysServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HolidaysCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysCreate",
            request_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysCreateResponse.FromString,
        )
        self.HolidaysRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysRead",
            request_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysReadResponse.FromString,
        )
        self.HolidaysUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysUpdate",
            request_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysUpdateResponse.FromString,
        )
        self.HolidaysDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysDelete",
            request_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysDeleteResponse.FromString,
        )


class HolidaysServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HolidaysCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HolidaysRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HolidaysUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HolidaysDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_HolidaysServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "HolidaysCreate": grpc.unary_unary_rpc_method_handler(
            servicer.HolidaysCreate,
            request_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysCreateResponse.SerializeToString,
        ),
        "HolidaysRead": grpc.unary_unary_rpc_method_handler(
            servicer.HolidaysRead,
            request_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysReadResponse.SerializeToString,
        ),
        "HolidaysUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.HolidaysUpdate,
            request_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysUpdateResponse.SerializeToString,
        ),
        "HolidaysDelete": grpc.unary_unary_rpc_method_handler(
            servicer.HolidaysDelete,
            request_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.holidays.HolidaysService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class HolidaysService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HolidaysCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysCreate",
            v1_dot_rules_dot_holidays__pb2.HolidaysCreateRequest.SerializeToString,
            v1_dot_rules_dot_holidays__pb2.HolidaysCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HolidaysRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysRead",
            v1_dot_rules_dot_holidays__pb2.HolidaysReadRequest.SerializeToString,
            v1_dot_rules_dot_holidays__pb2.HolidaysReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HolidaysUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysUpdate",
            v1_dot_rules_dot_holidays__pb2.HolidaysUpdateRequest.SerializeToString,
            v1_dot_rules_dot_holidays__pb2.HolidaysUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HolidaysDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysDelete",
            v1_dot_rules_dot_holidays__pb2.HolidaysDeleteRequest.SerializeToString,
            v1_dot_rules_dot_holidays__pb2.HolidaysDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
