# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/holidays.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/rules/holidays.proto\x12"pro.omni.oms.api.v1.rules.holidays\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb4\x01\n\x08Holidays\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x03(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x80\x01\n\x15HolidaysCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x03(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16HolidaysCreateResponse\x12>\n\x08holidays\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf1\x02\n\x13HolidaysReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdc\x01\n\x14HolidaysReadResponse\x12>\n\x08holidays\x18\x01 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8f\x01\n\x15HolidaysUpdateRequest\x12>\n\x08holidays\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16HolidaysUpdateResponse\x12>\n\x08holidays\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"[\n\x15HolidaysDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16HolidaysDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0fHolidaysService\x12\x89\x01\n\x0eHolidaysCreate\x12\x39.pro.omni.oms.api.v1.rules.holidays.HolidaysCreateRequest\x1a:.pro.omni.oms.api.v1.rules.holidays.HolidaysCreateResponse"\x00\x12\x83\x01\n\x0cHolidaysRead\x12\x37.pro.omni.oms.api.v1.rules.holidays.HolidaysReadRequest\x1a\x38.pro.omni.oms.api.v1.rules.holidays.HolidaysReadResponse"\x00\x12\x89\x01\n\x0eHolidaysUpdate\x12\x39.pro.omni.oms.api.v1.rules.holidays.HolidaysUpdateRequest\x1a:.pro.omni.oms.api.v1.rules.holidays.HolidaysUpdateResponse"\x00\x12\x89\x01\n\x0eHolidaysDelete\x12\x39.pro.omni.oms.api.v1.rules.holidays.HolidaysDeleteRequest\x1a:.pro.omni.oms.api.v1.rules.holidays.HolidaysDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.holidays_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_HOLIDAYS"]._serialized_start = 115
    _globals["_HOLIDAYS"]._serialized_end = 295
    _globals["_HOLIDAYSCREATEREQUEST"]._serialized_start = 298
    _globals["_HOLIDAYSCREATEREQUEST"]._serialized_end = 426
    _globals["_HOLIDAYSCREATERESPONSE"]._serialized_start = 429
    _globals["_HOLIDAYSCREATERESPONSE"]._serialized_end = 592
    _globals["_HOLIDAYSREADREQUEST"]._serialized_start = 595
    _globals["_HOLIDAYSREADREQUEST"]._serialized_end = 964
    _globals["_HOLIDAYSREADRESPONSE"]._serialized_start = 967
    _globals["_HOLIDAYSREADRESPONSE"]._serialized_end = 1187
    _globals["_HOLIDAYSUPDATEREQUEST"]._serialized_start = 1190
    _globals["_HOLIDAYSUPDATEREQUEST"]._serialized_end = 1333
    _globals["_HOLIDAYSUPDATERESPONSE"]._serialized_start = 1336
    _globals["_HOLIDAYSUPDATERESPONSE"]._serialized_end = 1499
    _globals["_HOLIDAYSDELETEREQUEST"]._serialized_start = 1501
    _globals["_HOLIDAYSDELETEREQUEST"]._serialized_end = 1592
    _globals["_HOLIDAYSDELETERESPONSE"]._serialized_start = 1594
    _globals["_HOLIDAYSDELETERESPONSE"]._serialized_end = 1693
    _globals["_HOLIDAYSSERVICE"]._serialized_start = 1696
    _globals["_HOLIDAYSSERVICE"]._serialized_end = 2267
# @@protoc_insertion_point(module_scope)
