# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import picking_type_pb2 as v1_dot_stock_dot_picking__type__pb2


class PickingTypeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PickingTypeCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeCreate",
            request_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateResponse.FromString,
        )
        self.PickingTypeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeRead",
            request_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeReadResponse.FromString,
        )
        self.PickingTypeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeUpdate",
            request_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateResponse.FromString,
        )
        self.PickingTypeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeDelete",
            request_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteResponse.FromString,
        )


class PickingTypeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PickingTypeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PickingTypeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "PickingTypeCreate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeCreate,
            request_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateResponse.SerializeToString,
        ),
        "PickingTypeRead": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeRead,
            request_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeReadResponse.SerializeToString,
        ),
        "PickingTypeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeUpdate,
            request_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateResponse.SerializeToString,
        ),
        "PickingTypeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeDelete,
            request_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.picking_type.PickingTypeService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class PickingTypeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PickingTypeCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeCreate",
            v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeRead",
            v1_dot_stock_dot_picking__type__pb2.PickingTypeReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__type__pb2.PickingTypeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeUpdate",
            v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeDelete",
            v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
