# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import warehouse_hierarchy_pb2 as v1_dot_rules_dot_warehouse__hierarchy__pb2


class WarehouseHierarchyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WarehouseHierarchyCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyCreate",
            request_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateResponse.FromString,
        )
        self.WarehouseHierarchyRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyRead",
            request_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadResponse.FromString,
        )
        self.WarehouseHierarchyUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyUpdate",
            request_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateResponse.FromString,
        )
        self.WarehouseHierarchyDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyDelete",
            request_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteResponse.FromString,
        )


class WarehouseHierarchyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def WarehouseHierarchyCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseHierarchyRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseHierarchyUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseHierarchyDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WarehouseHierarchyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "WarehouseHierarchyCreate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseHierarchyCreate,
            request_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateResponse.SerializeToString,
        ),
        "WarehouseHierarchyRead": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseHierarchyRead,
            request_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadResponse.SerializeToString,
        ),
        "WarehouseHierarchyUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseHierarchyUpdate,
            request_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateResponse.SerializeToString,
        ),
        "WarehouseHierarchyDelete": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseHierarchyDelete,
            request_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class WarehouseHierarchyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def WarehouseHierarchyCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyCreate",
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseHierarchyRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyRead",
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseHierarchyUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyUpdate",
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseHierarchyDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyDelete",
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
