# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/special_conditions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!v1/rules/special_conditions.proto\x12,pro.omni.oms.api.v1.rules.special_conditions\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"j\n\x17SpecialConditionsValues\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x15\n\rfamily_doc_id\x18\x02 \x01(\t\x12\x12\n\ngroup_code\x18\x03 \x01(\t\x12\x16\n\x0e\x61ttribute_code\x18\x04 \x01(\t"\x92\x02\n\x11SpecialConditions\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x61\n\x12special_conditions\x18\x03 \x03(\x0b\x32\x45.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsValues\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xde\x01\n\x1eSpecialConditionsCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x61\n\x12special_conditions\x18\x02 \x03(\x0b\x32\x45.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsValues\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc9\x01\n\x1fSpecialConditionsCreateResponse\x12[\n\x12special_conditions\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditions\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfa\x02\n\x1cSpecialConditionsReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x83\x02\n\x1dSpecialConditionsReadResponse\x12\\\n\x13\x64\x65livery_categories\x18\x01 \x03(\x0b\x32?.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditions\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb4\x01\n\x1eSpecialConditionsUpdateRequest\x12Z\n\x11\x64\x65livery_category\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditions\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc8\x01\n\x1fSpecialConditionsUpdateResponse\x12Z\n\x11\x64\x65livery_category\x18\x01 \x01(\x0b\x32?.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditions\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"d\n\x1eSpecialConditionsDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"l\n\x1fSpecialConditionsDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x80\x06\n\x18SpecialConditionsService\x12\xb8\x01\n\x17SpecialConditionsCreate\x12L.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsCreateRequest\x1aM.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsCreateResponse"\x00\x12\xb2\x01\n\x15SpecialConditionsRead\x12J.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsReadRequest\x1aK.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsReadResponse"\x00\x12\xb8\x01\n\x17SpecialConditionsUpdate\x12L.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsUpdateRequest\x1aM.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsUpdateResponse"\x00\x12\xb8\x01\n\x17SpecialConditionsDelete\x12L.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsDeleteRequest\x1aM.pro.omni.oms.api.v1.rules.special_conditions.SpecialConditionsDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.special_conditions_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SPECIALCONDITIONSVALUES"]._serialized_start = 134
    _globals["_SPECIALCONDITIONSVALUES"]._serialized_end = 240
    _globals["_SPECIALCONDITIONS"]._serialized_start = 243
    _globals["_SPECIALCONDITIONS"]._serialized_end = 517
    _globals["_SPECIALCONDITIONSCREATEREQUEST"]._serialized_start = 520
    _globals["_SPECIALCONDITIONSCREATEREQUEST"]._serialized_end = 742
    _globals["_SPECIALCONDITIONSCREATERESPONSE"]._serialized_start = 745
    _globals["_SPECIALCONDITIONSCREATERESPONSE"]._serialized_end = 946
    _globals["_SPECIALCONDITIONSREADREQUEST"]._serialized_start = 949
    _globals["_SPECIALCONDITIONSREADREQUEST"]._serialized_end = 1327
    _globals["_SPECIALCONDITIONSREADRESPONSE"]._serialized_start = 1330
    _globals["_SPECIALCONDITIONSREADRESPONSE"]._serialized_end = 1589
    _globals["_SPECIALCONDITIONSUPDATEREQUEST"]._serialized_start = 1592
    _globals["_SPECIALCONDITIONSUPDATEREQUEST"]._serialized_end = 1772
    _globals["_SPECIALCONDITIONSUPDATERESPONSE"]._serialized_start = 1775
    _globals["_SPECIALCONDITIONSUPDATERESPONSE"]._serialized_end = 1975
    _globals["_SPECIALCONDITIONSDELETEREQUEST"]._serialized_start = 1977
    _globals["_SPECIALCONDITIONSDELETEREQUEST"]._serialized_end = 2077
    _globals["_SPECIALCONDITIONSDELETERESPONSE"]._serialized_start = 2079
    _globals["_SPECIALCONDITIONSDELETERESPONSE"]._serialized_end = 2187
    _globals["_SPECIALCONDITIONSSERVICE"]._serialized_start = 2190
    _globals["_SPECIALCONDITIONSSERVICE"]._serialized_end = 2958
# @@protoc_insertion_point(module_scope)
