# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import delivery_schedule_pb2 as v1_dot_rules_dot_delivery__schedule__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/rules/warehouse.proto\x12#pro.omni.oms.api.v1.rules.warehouse\x1a\x11\x63ommon/base.proto\x1a v1/rules/delivery_schedule.proto"\xb3\x02\n\tWarehouse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x18\n\x10warehouse_sql_id\x18\x04 \x01(\x05\x12\x1a\n\x12locality_available\x18\x05 \x01(\t\x12\x18\n\x10loc_stock_sql_id\x18\x06 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12X\n\x11schedule_template\x18\x08 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_schedule.DeliverySchedule\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xef\x01\n\x16WarehouseCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x18\n\x10warehouse_sql_id\x18\x03 \x01(\x05\x12\x1a\n\x12locality_available\x18\x04 \x01(\t\x12\x18\n\x10loc_stock_sql_id\x18\x05 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12\x1c\n\x14schedule_template_id\x18\x07 \x01(\t\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x17WarehouseCreateResponse\x12\x41\n\twarehouse\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf2\x02\n\x14WarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe1\x01\n\x15WarehouseReadResponse\x12\x42\n\nwarehouses\x18\x01 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x93\x01\n\x16WarehouseUpdateRequest\x12\x41\n\twarehouse\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa7\x01\n\x17WarehouseUpdateResponse\x12\x41\n\twarehouse\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"v\n\x16WarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x10warehouse_sql_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"d\n\x17WarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd0\x04\n\x10WarehouseService\x12\x8e\x01\n\x0fWarehouseCreate\x12;.pro.omni.oms.api.v1.rules.warehouse.WarehouseCreateRequest\x1a<.pro.omni.oms.api.v1.rules.warehouse.WarehouseCreateResponse"\x00\x12\x88\x01\n\rWarehouseRead\x12\x39.pro.omni.oms.api.v1.rules.warehouse.WarehouseReadRequest\x1a:.pro.omni.oms.api.v1.rules.warehouse.WarehouseReadResponse"\x00\x12\x8e\x01\n\x0fWarehouseUpdate\x12;.pro.omni.oms.api.v1.rules.warehouse.WarehouseUpdateRequest\x1a<.pro.omni.oms.api.v1.rules.warehouse.WarehouseUpdateResponse"\x00\x12\x8e\x01\n\x0fWarehouseDelete\x12;.pro.omni.oms.api.v1.rules.warehouse.WarehouseDeleteRequest\x1a<.pro.omni.oms.api.v1.rules.warehouse.WarehouseDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSE"]._serialized_start = 119
    _globals["_WAREHOUSE"]._serialized_end = 426
    _globals["_WAREHOUSECREATEREQUEST"]._serialized_start = 429
    _globals["_WAREHOUSECREATEREQUEST"]._serialized_end = 668
    _globals["_WAREHOUSECREATERESPONSE"]._serialized_start = 671
    _globals["_WAREHOUSECREATERESPONSE"]._serialized_end = 838
    _globals["_WAREHOUSEREADREQUEST"]._serialized_start = 841
    _globals["_WAREHOUSEREADREQUEST"]._serialized_end = 1211
    _globals["_WAREHOUSEREADRESPONSE"]._serialized_start = 1214
    _globals["_WAREHOUSEREADRESPONSE"]._serialized_end = 1439
    _globals["_WAREHOUSEUPDATEREQUEST"]._serialized_start = 1442
    _globals["_WAREHOUSEUPDATEREQUEST"]._serialized_end = 1589
    _globals["_WAREHOUSEUPDATERESPONSE"]._serialized_start = 1592
    _globals["_WAREHOUSEUPDATERESPONSE"]._serialized_end = 1759
    _globals["_WAREHOUSEDELETEREQUEST"]._serialized_start = 1761
    _globals["_WAREHOUSEDELETEREQUEST"]._serialized_end = 1879
    _globals["_WAREHOUSEDELETERESPONSE"]._serialized_start = 1881
    _globals["_WAREHOUSEDELETERESPONSE"]._serialized_end = 1981
    _globals["_WAREHOUSESERVICE"]._serialized_start = 1984
    _globals["_WAREHOUSESERVICE"]._serialized_end = 2576
# @@protoc_insertion_point(module_scope)
