# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import stock_security_pb2 as v1_dot_rules_dot_stock__security__pb2


class StockSecurityServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StockSecurityCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security.StockSecurityService/StockSecurityCreate",
            request_serializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityCreateResponse.FromString,
        )
        self.StockSecurityRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security.StockSecurityService/StockSecurityRead",
            request_serializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityReadResponse.FromString,
        )
        self.StockSecurityUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security.StockSecurityService/StockSecurityUpdate",
            request_serializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityUpdateResponse.FromString,
        )
        self.StockSecurityDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.stock_security.StockSecurityService/StockSecurityDelete",
            request_serializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityDeleteResponse.FromString,
        )


class StockSecurityServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StockSecurityCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockSecurityDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StockSecurityServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StockSecurityCreate": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityCreate,
            request_deserializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityCreateResponse.SerializeToString,
        ),
        "StockSecurityRead": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityRead,
            request_deserializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityReadResponse.SerializeToString,
        ),
        "StockSecurityUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityUpdate,
            request_deserializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityUpdateResponse.SerializeToString,
        ),
        "StockSecurityDelete": grpc.unary_unary_rpc_method_handler(
            servicer.StockSecurityDelete,
            request_deserializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_stock__security__pb2.StockSecurityDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.stock_security.StockSecurityService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StockSecurityService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StockSecurityCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security.StockSecurityService/StockSecurityCreate",
            v1_dot_rules_dot_stock__security__pb2.StockSecurityCreateRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__pb2.StockSecurityCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security.StockSecurityService/StockSecurityRead",
            v1_dot_rules_dot_stock__security__pb2.StockSecurityReadRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__pb2.StockSecurityReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security.StockSecurityService/StockSecurityUpdate",
            v1_dot_rules_dot_stock__security__pb2.StockSecurityUpdateRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__pb2.StockSecurityUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockSecurityDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.stock_security.StockSecurityService/StockSecurityDelete",
            v1_dot_rules_dot_stock__security__pb2.StockSecurityDeleteRequest.SerializeToString,
            v1_dot_rules_dot_stock__security__pb2.StockSecurityDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
